Nautobot Apps - Nautobot Documentation

Skip to content

# Nautobot Apps Overview

To view and search the full list of Apps, head over to the Nautobot App Ecosystem Page on networktocode.com. Below you will only find links to the documentation for the apps listed in the table.

## Community-Developed Nautobot Apps

Find out more about what documentation is available for the various community developed Nautobot Apps by visiting the Community Apps page.

## Network to Code Nautobot Apps

These Nautobot Apps have their documentation hosted as a subproject of this docs site and they are built and structured according to the Network To Code documentation standards.

| App Name | Description
--- | --- | ---
| Nautobot ChatOps | Add chatbot functionality to Nautobot to facilitate getting data from Nautobot directly from a chat platform. The ChatOps app is a multi-platform chatbot for network operations and engineering teams. It is built to seamlessly work across Slack, MS Teams, WebEx Teams, and Mattermost, but also as a framework to help developers add more chat platforms in the future.
| Nautobot Data Validation Engine | Create custom, user-defined validation rules that can be used to enforce business constraints on the data within Nautobot.
| Nautobot Device Lifecycle Management | Make related associations to Devices, Device Types, and Inventory Items to help provide data about the hardware end of life notices, appropriate software versions to be running on the devices, and the maintenance contracts associated with devices.
| Nautobot Device Onboarding | Simplify the onboarding process of a new device by allowing the user to specify a small amount of info and having the plugin populate a much larger amount of device data in Nautobot.
| Nautobot Firewall Models | Construct firewall policies in Nautobot with the help of the provided collection of relevant models.
| Nautobot Golden Configuration | Automate configuration backups, perform configuration compliance, and generate intended configurations.
| Nautobot Plugin Nornir | Provides a small shim layer between nornir-nautobot and other plugins. The primary abilities that the plugin provides are a native Nornir ORM based inventory and a credential manager.
| Nautobot Single Source of Truth (SSoT) | Integrate and synchronize data between various "source of truth" (SoT) systems, with Nautobot acting as a central clearinghouse for data - a Single Source of Truth